@@ -1,35 +1,39 @@
+".packageName" <- "CoCo"
+
 ".First.lib" <-
 function (lib, pkg) 
 {
     require(methods)
-    require(CoCoCore)
     require(CoCoObjects)
+    require(CoCoCore)
     require(CoCoRaw)
 }
+
 ".onAttach" <-
 function (lib, pkg) 
 {
-    # require(tcltk)
-    # require(dynamicGraph)
+    require(CoCoRaw)
+
     # .First.lib.CoCoCore(lib, pkg)
     # .First.lib.CoCoObjects(lib, pkg)
     # .First.lib.CoCoDynamicGraph(lib, pkg)
-    require(CoCoRaw)
+
+    # message("'.onAttach' of CoCo")
 }
+
 ".onLoad" <-
 function (lib, pkg) 
 {
     require(CoCoRaw)
-    # "dG" <- function(object, ...) {
-    #     require(CoCoGraph)
-    #     dg(object, ...)
-    # }
+
     .First.lib.CoCoCore(lib, pkg)
     # .First.lib.CoCoObjects(lib, pkg)
     # .First.lib.CoCoDynamicGraph(lib, pkg)
+
+    # message("'.onLoad' of CoCo")
 }
+
 "dG" <- function(object, ...) {
     require(CoCoGraph)
-    # CoCoGraph::dg(object, ...)
     dg(object, ...)
 }
