@@ -1,3 +1,40 @@
+".packageName" <- "CoCoCore"
+
+
+".First.lib.CoCoCore" <-
+function (lib, pkg) 
+{
+    my.assign(".char.ok", FALSE, frame = 0)
+    coco.load()
+
+    .clear.coco.objects(pos = .GlobalEnv)
+}
+
+".First.lib" <-
+function (lib, pkg) 
+{
+    # require(methods)
+    # require(CoCoObjects)
+
+    library.dynam("CoCoCore", pkg, lib)
+    .First.lib.CoCoCore(lib, pkg)
+}
+
+".onAttach" <-
+function (lib, pkg) 
+{
+    require(CoCoObjects)
+}
+
+".onLoad" <-
+function (lib, pkg) 
+{
+    require(CoCoObjects)
+
+    library.dynam("CoCoCore", pkg, lib)
+    # .First.lib.CoCoCore(lib, pkg)
+}
+
 
 # trace.call.coco <- FALSE;
 
@@ -301,41 +338,6 @@ function (action)
 ".false.if.NULL" <-
 function (arg) 
 ifelse(length(arg) == 0, FALSE, arg)
-".First.lib" <-
-function (lib, pkg) 
-{
-    # require(methods)
-    # require(CoCoObjects)
-    library.dynam("CoCoCore", pkg, lib)
-    .First.lib.CoCoCore(lib, pkg)
-}
-".First.lib.CoCoCore" <-
-function (lib, pkg) 
-{
-    my.assign(".char.ok", FALSE, frame = 0)
-    coco.load()
-#   cat("For documentation see, Badsberg, J.H.: A guide to CoCo,                \n")
-#   cat("JSS, 2001 ( http://www.jstatsoft.org/v06/i04/ )                        \n")
-#   cat("and Badsberg, J.H.: Xlisp+CoCo, Aalborg, 1996.                         \n")
-#   cat("The manual pages of CoCo in R will currently only give you             \n")
-#   cat("the form of arguments of the functions. The teen calls                 \n")
-#   cat("''                                                                     \n")
-#   cat("      data(Reinis);                                                    \n")
-#   cat("      CoCoObject <- makeCoCo();                                        \n")
-#   cat("      enterTable(Reinis, object = CoCoObject);                         \n")
-#   cat("      fullModel <- makeModel(enterModel(\"*\", object = CoCoObject));    \n")
-#   cat("      library(CoCoGraph);                                              \n")
-#   cat("      fullGraph <- dynamic.Graph(fullModel, title = \"Full\");           \n")
-#   cat("      backward(recursive = TRUE, object = CoCoObject);                 \n")
-#   cat("      eh(object = CoCoObject);                                         \n")
-#   cat("      lastModel <- makeModel(\"last\", object = CoCoObject);             \n")
-#   cat("      backwardGraph <- dynamic.Graph(lastModel, title = \"Last\");       \n")
-#   cat("''                                                                     \n")
-#   cat("will give you a small example.                                         \n")
-#   cat("Please quit by 'quitCoCo()' to remove temporary files.                 \n")
-#   cat("\n")
-    .clear.coco.objects(pos = .GlobalEnv)
-}
 ".get.cocolib.name" <-
 function (x) 
 system("echo $COCOLIB", intern = TRUE)
@@ -380,6 +382,7 @@ function (sh.lib.name = NULL)
 {
     library.dynam("Mips") # 'pkg' and 'lib' ?
 }
+
 ".my.ascii" <-
 function () 
 sapply(0:127, function(i) parse(text = paste("\"\\", structure(i, 
@@ -415,10 +418,10 @@ sapply(0:127, function(i) parse(text = paste("\"\\", structure(i,
 ###     "w", "x", "y", "z", "{", "|", "}", "~", "\177")
 
 ".my.ascii" <- function()
-        c("\000","\001","\002","\003","\004","\005","\006","\007",
+        c("","\001","\002","\003","\004","\005","\006","\007",
           "\010","\011","\012","\013","\014","\015","\016","\017",
           "\020","\021","\022","\023","\024","\025","\026","\027",
-          "\030","\031","\000","\033","\034","\035","\036","\037",
+          "\030","\031","\032","\033","\034","\035","\036","\037",
           "\040","\041","\042","\043","\044","\045","\046","\047",
           "\050","\051","\052","\053","\054","\055","\056","\057",
           "\060","\061","\062","\063","\064","\065","\066","\067",
@@ -467,19 +470,6 @@ function (model.1, model.2, data = NULL, object = CoCoCore::.currentCoCo(),
                                  to.factor = to.factor, ...)
     return(result)
 }
-".onAttach" <-
-function (lib, pkg) 
-{
-    require(CoCoObjects)
-}
-".onLoad" <-
-function (lib, pkg) 
-{
-    require(CoCoObjects)
-    library.dynam("CoCoCore", pkg, lib)
-}
-# ".packageName" <-
-# "CoCoCore"
 ".return.factor.type.list" <-
 function (full = FALSE, number.variates = CoCoRaw::numberVariates(full = full, 
     object = object), object = CoCoCore::.currentCoCo()) 
