@@ -7,7 +7,7 @@ function (n = 65536, p = 65536, q = 1024, r = 65536, s = 65536,
     coco.init(n, p, q, r, s, ss, t, TRUE, title = title, type = type, 
         silent = silent, location = location, manager = manager, 
         sh.lib.name = sh.lib.name)
-    result <- .new.coco(.current.coco, type, uniq.title = uniq.title, 
+    result <- .new.coco(CoCoCore::.currentCoCo(), type, uniq.title = uniq.title, 
         title = title)
     size <- c(n, p, q, r, s, ss, t)
     names(size) <- c("n", "p", "q", "r", "s", "ss", "t")
@@ -15,5 +15,5 @@ function (n = 65536, p = 65536, q = 1024, r = 65536, s = 65536,
         location = location, manager = manager, silent = silent, 
         sh.lib.name = sh.lib.name))
     my.assign(".current.coco", result, frame = 0)
-    .current.coco
+    return(CoCoCore::.currentCoCo())
 }
