@@ -1,9 +1,9 @@
 "read.data" <-
-function (setslot = TRUE, object = .current.coco) 
+function (setslot = TRUE, object = CoCoCore::.currentCoCo()) 
 {
     .set.coco.value(object, ".invalid", append = TRUE, list(type = "read.data"))
     result <- coco.simple.command(88, FALSE, object = object)
     cat("\n")
-    extractData(object = object)
+    CoCoRaw::extractData(object = object)
     return(result)
 }
