@@ -1,5 +1,5 @@
 "read.q.list" <-
-function (set, setslot = TRUE, object = .current.coco) 
+function (set, setslot = TRUE, object = CoCoCore::.currentCoCo()) 
 {
     if (setslot) 
         .set.coco.value(object, ".invalid", append = TRUE, list(type = "read.q.list", 
