@@ -1,5 +1,5 @@
 "set.output" <-
-function (file.name, object = .current.coco) 
+function (file.name, object = CoCoCore::.currentCoCo()) 
 {
     call.coco.chars(27, file.name, FALSE, object = object)
 }
